/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2009-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl> 
 *
 *  2007-2009
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 *  2003-2007
 *     Martijn Steenbakkers <martijn@nikhef.nl>
 *     Gerben Venekamp <venekamp@nikhef.nl>
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *
 */


/*!
    \file   lcmaps_return_account_from_pem.h
    \brief  This interface returns the uid, gids and poolindex, i.e. leaseid,
            using LCMAPS and takes the user credential in PEM format as input
    \author Martijn Steenbakkers for the EU DataGrid.

    This interface returns the uid, gids and poolindex, i.e. leaseid, using LCMAPS.
    As input it requires the user credential in PEM format
    -# lcmaps_return_account_from_pem: interface function

    In general the behaviour of LCMAPS can be influenced by setting the following
    environment variables:
        Env variable                        Description
        (default value)
        ---------------                     -----------
        LCMAPS_LOG_FILE                     The logfile to which lcmaps log
        ("/var/log/lcmaps.log")             messages will be written

        LCMAPS_DB_FILE                      the location (name) of the lcmaps policy file
        (LCMAPS_ETC_DIR"/lcmaps.db")

        LCMAPS_POLICY_NAME                  the list of the lcmaps policies (in the
        ("acquisition_policy")              policy file) that should be evaluated until
                                            a policy succeeds. The policies are separated
                                            by ':', e.g. "policy_preferred:policy_fallback:".

        LCMAPS_LOG_STRING                   A string that will be prepended to all
        ("poolindex :")                     LCMAPS logging messages. If this variable is not
                                            set a default will be taken which includes a 
                                            timestamp

        LCMAPS_DEBUG_LEVEL                  The debug level influences the logging
        ("0")                               verbosity. values 0-5.

        LCMAPS_MODULES_DIR                  The directory in which modules can be found.
        ("")                                Note: may be overwritten by what is in
                                            the policy file (the convential method)

        LCMAPS_ETC_DIR                      The directory of the lcmaps policy files
        ("/opt/glite/etc/lcmaps")           and other config files. In this case this location
                                            is hardcoded to be "/opt/glite/etc/lcmaps", because this
                                            lcmaps interface is used by VO-services and, therefore, not
                                            controlled by the site.

        GRIDMAPDIR                          The directory in which the poolaccount leases
        ("")                                are registered.
                                            Note: may be overwritten by what is in
                                            the policy file (the convential method)

    \ingroup LcmapsInterface
*/

#ifndef LCMAPS_RETURN_ACCOUNT_FROM_PEM_H
#define LCMAPS_RETURN_ACCOUNT_FROM_PEM_H

#ifndef LCMAPS_RETURN_ACCOUNT_FROM_PEM_C
#   define LCMAPS_RETURN_ACCOUNT_FROM_PEM_C_STORAGE_CLASS extern
#else
#   define LCMAPS_RETURN_ACCOUNT_FROM_PEM_C_STORAGE_CLASS
#endif

/******************************************************************************
                             Include header files
******************************************************************************/
#include "lcmaps_account.h"

/******************************************************************************
                   Module definition
 *****************************************************************************/

/******************************************************************************
Function:   lcmaps_return_account_from_pem
Description:
    If LCMAPS is invoked via this interface it will return the user account info
    and poolindex, alternatively named leaseid, to the calling application.

Parameters:
    mapcounter:    :  The counter which will be added to the poolindex, effectively enabling
                      multiple account mappings
    pem_string:    :  The PEM-encoded string containing the user proxy
    plcmaps_account:  A structure that contains account information: (output)
                      uid, gids (primary and secondary) and the poolindex
                      Please use lcmaps_account_info_clean() to clean this
                      structure after use.
Returns:
    0: success
    1: failure
******************************************************************************/
/*!
    \fn lcmaps_return_account_from_pem(
        char * pem_string,
        int mapcounter,
        lcmaps_account_info_t * plcmaps_account
    )

    \brief Return the mapped account and poolindex
    If LCMAPS is invoked via this interface it will return the user account info
    and poolindex, alternatively named leaseid, to the calling application.

    \param mapcounter
            The counter which will be added to the poolindex, effectively enabling
            multiple account mappings
    \param pem_string
            The PEM-encoded string containing the user proxy
    \param plcmaps_account
            A structure that contains account information: (output)
            uid, gids (primary and secondary) and the poolindex
            Please use lcmaps_account_info_clean() to clean this
            structure after use.

    \retval 0 success.
    \retval 1 failure.
*/
LCMAPS_RETURN_ACCOUNT_FROM_PEM_C_STORAGE_CLASS int
lcmaps_return_account_from_pem(
        char * pem_string,
        int mapcounter,
        lcmaps_account_info_t * plcmaps_account
);
#endif /* LCMAPS_RETURN_POOLINDEX_WITHOUT_GSI_H */
